@@ -17,16 +17,7 @@
 
 #include "LogWeightTransducer.h"
 #include "HfstSymbolDefs.h"
-
-#ifdef _MSC_VER
-#include "back-ends/openfstwin/src/include/fst/fstlib.h"
-#else
-#if HAVE_OPENFST_UPSTREAM
 #include <fst/fstlib.h>
-#else
-#include "back-ends/openfst/src/include/fst/fstlib.h"
-#endif
-#endif // _MSC_VER
 
 namespace hfst { namespace implementations
 {
