@@ -12,16 +12,7 @@
 #include "HfstLookupFlagDiacritics.h"
 #include "HfstBasicTransducer.h"
 #include "ConvertTransducerFormat.h"
-
-#ifdef _MSC_VER
-#include "back-ends/openfstwin/src/include/fst/fstlib.h"
-#else
-#if HAVE_OPENFST_UPSTREAM
 #include <fst/fstlib.h>
-#else
-#include "back-ends/openfst/src/include/fst/fstlib.h"
-#endif
-#endif // _MSC_VER
 
 #if defined(USE_FOMA_EPSILON_REMOVAL) && defined(HAVE_FOMA)
 #include "FomaTransducer.h"
