@@ -8,16 +8,7 @@
 // information.
 
 #include "convert.h"
-
-#ifdef _MSC_VER
-#include "back-ends/openfstwin/src/include/fst/fstlib.h"
-#else
-#if HAVE_OPENFST_UPSTREAM
 #include <fst/fstlib.h>
-#else
-#include "back-ends/openfst/src/include/fst/fstlib.h"
-#endif
-#endif // _MSC_VER
 
 #ifndef _MSC_VER
 namespace fst
@@ -49,7 +40,7 @@ void write_transitions_from_state_placeholders(
                 TransitionW(
                     it->final, it->final_weight));
         }
-        
+
         // Then we iterate through the symbols each state has.
     // First we do a pass for epsilon and flags (they have to come
     // first), then everything else.
@@ -69,7 +60,7 @@ void write_transitions_from_state_placeholders(
                 transition_table,
                 state_placeholders,
                 flag_symbols);
-            
+
         }
     }
     for (unsigned int i = 1; i < it->symbol_to_transition_placeholder_v.size();
@@ -86,7 +77,7 @@ void write_transitions_from_state_placeholders(
     }
     }
 
-        
+
     // one final padding transition
     transition_table.append(hfst_ol::TransitionW(
                 false, hfst_ol::INFINITE_WEIGHT));
@@ -185,14 +176,14 @@ void ConvertTransducerAlphabet::inspect_node(
   if(visited_nodes.find(n) != visited_nodes.end())
     return;
   visited_nodes.insert(n);
-  
+
   std::set<std::string> input_symbols;
   for(ArcIterator aiter(*transducer,n); !aiter.Done(); aiter.Next())
   {
     StdArc arc = aiter.Value();
     std::string input_symbol_string =
     transducer->InputSymbols()->Find(arc.ilabel);
-    
+
     if(!FdOperation::is_diacritic(input_symbol_string))
       input_symbols.insert(input_symbol_string);
     all_symbol_set.insert(input_symbol_string);
@@ -200,11 +191,11 @@ void ConvertTransducerAlphabet::inspect_node(
       all_symbol_set.insert(transducer->OutputSymbols()->Find(arc.olabel));
     else
       all_symbol_set.insert(transducer->InputSymbols()->Find(arc.olabel));
-    
+
     inspect_node(
     arc.nextstate, visited_nodes, symbol_count_map, all_symbol_set);
   }
-  
+
   for(std::set<std::string>::const_iterator it=input_symbols.begin();
       it!=input_symbols.end(); it++)
     symbol_count_map[ofst_symbol_table->Find(*it)]++;
@@ -231,7 +222,7 @@ void ConvertTransducerAlphabet::populate_symbol_table(
     else
       count_keys.insert(std::pair<unsigned int,int64>(0,it->first));
   }
-  
+
   symbol_table.push_back(ofst_symbol_table->Find((int64)0));
   for (std::multimap<unsigned int,int64>::reverse_iterator it =
        count_keys.rbegin();
@@ -264,7 +255,7 @@ void ConvertTransducerAlphabet::set_maps()
       }
     }
   }
-  
+
   if(transducer->OutputSymbols() != NULL)
   {
     for(fst::SymbolTableIterator it(*(transducer->OutputSymbols())); !it.Done()
@@ -291,14 +282,14 @@ ConvertTransducerAlphabet::ConvertTransducerAlphabet(TransduceR* t):
   ofst_symbol_table = t->InputSymbols()->Copy();
   if(t->OutputSymbols() != NULL)
     ofst_symbol_table->AddTable(*(t->OutputSymbols()));
-  
+
   OfstSymbolCountMap symbol_count_map;
   SymbolSet all_symbol_set;
-  
+
   get_symbol_info(symbol_count_map, all_symbol_set);
   populate_symbol_table(symbol_count_map, all_symbol_set);
   set_maps();
-  
+
   delete ofst_symbol_table;
 }
 
@@ -307,7 +298,7 @@ void ConvertTransducerAlphabet::display() const
   std::cout << "Final reordered symbol table:" << std::endl;
   for(size_t i=0;i<symbol_table.size();i++)
     std::cout << i << ": " << symbol_table[i] << std::endl;
-  
+
   std::cout << "Initial input symbols (old/new: string):" << std::endl;
   for(fst::SymbolTableIterator i(*(transducer->InputSymbols()));
       !i.Done(); i.Next())
@@ -494,7 +485,7 @@ void ConvertFstState::set_transition_indices(void)
 {
   SymbolNumber previous_symbol = NO_SYMBOL_NUMBER;
   SymbolNumber position = 0;
-  
+
   bool zero_transitions = false;
   for (ConvertTransitionSet::iterator it=transitions.begin();
        it!=transitions.end(); ++it)
@@ -509,7 +500,7 @@ void ConvertFstState::set_transition_indices(void)
         if(!zero_transitions)
         {
           transition_indices.insert(new ConvertTransitionIndex(0, t));
-          
+
           previous_symbol = input_symbol;
           zero_transitions =true;
         }
@@ -517,7 +508,7 @@ void ConvertFstState::set_transition_indices(void)
       else
       {
         transition_indices.insert(new ConvertTransitionIndex(input_symbol, t));
-        
+
         previous_symbol = input_symbol;
       }
     }
@@ -529,14 +520,14 @@ void ConvertFstState::set_transition_indices(void)
 SymbolNumberSet * ConvertFstState::get_input_symbols(void) const
 {
   SymbolNumberSet * input_symbols = new SymbolNumberSet;
-  
+
   for(ConvertTransitionIndexSet::const_iterator it=transition_indices.begin();
       it!=transition_indices.end(); ++it)
   {
     ConvertTransitionIndex * i = *it;
     input_symbols->insert(i->get_input_symbol());
   }
-  
+
   return input_symbols;
 }
 
@@ -544,7 +535,7 @@ TransitionTableIndex ConvertFstState::set_transition_table_indices(
     TransitionTableIndex place)
 {
   first_transition_index = place;
-  
+
   // lay out the transitions sequentially with a space between each state
   for(ConvertTransitionSet::iterator it=transitions.begin();
       it!=transitions.end(); ++it)
@@ -554,7 +545,7 @@ TransitionTableIndex ConvertFstState::set_transition_table_indices(
     ++place;
   }
   ++place;
-  
+
   // update the TransitionIndex's to store the table location of the
   // associated transition
   for(ConvertTransitionIndexSet::iterator it=transition_indices.begin();
@@ -564,7 +555,7 @@ TransitionTableIndex ConvertFstState::set_transition_table_indices(
     i->set_first_transition_index(
     i->get_first_transition()->get_table_index());
   }
-  
+
   return place;
 }
 
@@ -583,16 +574,16 @@ void ConvertFstState::insert_transition_indices(
   // entries in the transition index table
   if(!is_big_state() && !is_start_state())
     return;
-  
+
   TransitionTableIndex i = table_index;
-  
+
   if(final)
     index_table.set(
     i, T(index_table[i].get_input_symbol(),
          *reinterpret_cast<const TransitionTableIndex*>(&weight)));
-  
+
   ++i;
-  
+
   for(ConvertTransitionIndexSet::const_iterator it=transition_indices.begin();
       it!=transition_indices.end(); ++it)
   {
@@ -611,7 +602,7 @@ TransitionTableIndex ConvertFstState::append_transitions(
     transition_table.append(T(final, weight));
     ++place;
   }
-  
+
   for(ConvertTransitionSet::const_iterator it=transitions.begin();
       it!=transitions.end(); ++it)
   {
@@ -651,20 +642,20 @@ bool ConvertTransitionTableIndices::state_fits(SymbolNumberSet * input_symbols,
   if((indices.at(index) == EMPTY_START) ||
      (indices.at(index) == OCCUPIED_START))
     return false;
-  
+
   if(final_state && (indices.at(index) == OCCUPIED))
     return false;
-  
+
   // The input symbols start after the finality indicator.
   PlaceHolderVector::size_type input_symbol_start = index+1;
-  
+
   // The node fits, if every one of its input symbols goes on
   // an EMPTY or EMPTY_START index.
   for(SymbolNumberSet::iterator it=input_symbols->begin();
       it!=input_symbols->end(); ++it)
   {
     SymbolNumber input_symbol = *it;
-    
+
     if((indices.at(input_symbol_start + input_symbol) == OCCUPIED) ||
        (indices.at(input_symbol_start + input_symbol) == OCCUPIED_START))
       return false;
@@ -682,10 +673,10 @@ void ConvertTransitionTableIndices::insert_state(
     indices.at(index) = OCCUPIED_START;
   else
     indices.at(index) = EMPTY_START;
-  
+
   // The input symbols start after the finality indicator.
   PlaceHolderVector::size_type input_symbol_start = index+1;
-  
+
   for(SymbolNumberSet::iterator it=input_symbols->begin();
       it!=input_symbols->end(); ++it)
   {
@@ -715,7 +706,7 @@ PlaceHolderVector::size_type ConvertTransitionTableIndices::add_state(
     lower_bound_test_count = 0;
     if(indices.size() > 2000 && lower_bound < (indices.size() - 2000))
       lower_bound = indices.size() - 1000;
-    
+
     ++lower_bound;
   }
 
@@ -730,12 +721,12 @@ PlaceHolderVector::size_type ConvertTransitionTableIndices::add_state(
         << "\r";
 #endif
   bool final_state = state->is_final();
-  
+
   SymbolNumberSet * state_input_symbols =
     state->get_input_symbols();
-  
+
   ++lower_bound_test_count;
-  
+
   for(PlaceHolderVector::size_type index=lower_bound; index<indices.size();
       ++index)
   {
@@ -746,7 +737,7 @@ PlaceHolderVector::size_type ConvertTransitionTableIndices::add_state(
     //}
     if((index + number_of_input_symbols + 1) >= indices.size())
       get_more_space();
-    
+
     if(state_fits(state_input_symbols,final_state,index))
     {
       insert_state(state_input_symbols,final_state,index);
@@ -766,7 +757,7 @@ void ConvertTransducerHeader::full_traversal(
     return;
   visited_nodes.insert(n);
   nodes_in_path.insert(n);
-  
+
   if(h.weighted && !h.has_unweighted_input_epsilon_cycles)
   {
     StateIdSet epsilon_nodes;
@@ -777,10 +768,10 @@ void ConvertTransducerHeader::full_traversal(
     StateIdSet epsilon_nodes;
     find_input_epsilon_cycles(n,n,epsilon_nodes,false,tr,h);
   }
-  
+
   OfstSymbolSet node_input_symbols;
   LabelSet transition_labels;
-  
+
   for(ArcIterator aiter(*tr,n); !aiter.Done(); aiter.Next())
   {
     StdArc a = aiter.Value();
@@ -788,31 +779,31 @@ void ConvertTransducerHeader::full_traversal(
     l.input_symbol = a.ilabel;
     l.output_symbol = a.olabel;
     StateId target = a.nextstate;
-    
+
     h.number_of_transitions++;
     if(!FdOperation::is_diacritic(tr->InputSymbols()->Find(a.ilabel)))
       all_input_symbols.insert(a.ilabel);
-    
+
     if(l.input_symbol == 0)
     {
       h.has_input_epsilon_transitions = true;
       if(l.output_symbol == 0)
         h.has_epsilon_epsilon_transitions = true;
     }
-    
+
     if(node_input_symbols.find(l.input_symbol) != node_input_symbols.end())
       h.input_deterministic = false;
     else
       node_input_symbols.insert(l.input_symbol);
-    
+
     if(transition_labels.find(l) != transition_labels.end())
       h.deterministic = false;
     else
       transition_labels.insert(l);
-    
+
     if(nodes_in_path.find(target) != nodes_in_path.end())
       h.cyclic = true;
-    
+
     full_traversal(h, tr, target, visited_nodes, nodes_in_path,
            all_input_symbols);
   }
@@ -834,7 +825,7 @@ void ConvertTransducerHeader::find_input_epsilon_cycles(
       if(a.weight != StdArc::Weight::Zero())
         continue;
     }
-    
+
     StateId target = a.nextstate;
     if (start == target )
     {
@@ -843,7 +834,7 @@ void ConvertTransducerHeader::find_input_epsilon_cycles(
       h.has_input_epsilon_cycles = true;
       return;
     }
-    
+
     if(epsilon_targets.find(target) != epsilon_targets.end())
     {
       epsilon_targets.insert(target);
@@ -878,12 +869,12 @@ void ConvertTransducerHeader::compute_header(TransducerHeader& header,
   header.has_input_epsilon_transitions = false;
   header.has_input_epsilon_cycles = false;
   header.has_unweighted_input_epsilon_cycles = false;
-  
+
   StateIdSet nodes, nodes_in_path;
   OfstSymbolSet input_symbols;
   input_symbols.insert(0);
   full_traversal(header, t, t->Start(), nodes, nodes_in_path, input_symbols);
-  
+
   header.number_of_input_symbols = input_symbols.size();
   header.number_of_states = nodes.size();
   if(!header.weighted)
@@ -918,16 +909,16 @@ void ConvertTransducer::set_transition_table_indices(void)
 void ConvertTransducer::set_index_table_indices(void)
 {
   StateSet state_set;
-  
+
   for(ConvertFstStateVector::iterator it=states.begin()+1;
       it != states.end(); ++it)
       state_set.insert(*it);
-  
+
   ConvertFstState * start_state = *states.begin();
   TransitionTableIndex start_state_index = fst_indices->add_state(start_state);
-  
+
   start_state->set_table_index(start_state_index);
-  
+
   for(StateSet::reverse_iterator it=state_set.rbegin();
       it!=state_set.rend(); ++it)
   {
@@ -944,10 +935,10 @@ void ConvertTransducer::set_index_table_indices(void)
         throw;
       }
     }
-    
+
     state->set_table_index(state_index);
   }
-  
+
   // now that the state object's all know their table location, update the
   // transition objects with that information
   for(ConvertFstStateVector::const_iterator it=states.begin();
@@ -988,7 +979,7 @@ TransitionTableIndex ConvertTransducer::count_transitions(void) const
   {
     // Separator between states;
     ++transition_count;
-    
+
     transition_count += (*it)->number_of_transitions();
   }
   return transition_count;
@@ -1027,14 +1018,14 @@ TransducerTable<T> ConvertTransducer::make_index_table(
     TransitionTableIndex index_table_size) const
 {
   TransducerTable<T> index_table(index_table_size, T());
-  
+
   for(ConvertFstStateVector::const_iterator it=states.begin();
       it!=states.end(); ++it)
   {
     ConvertFstState * state = *it;
     state->insert_transition_indices(index_table);
   }
-  
+
   return index_table;
 }
 
@@ -1049,7 +1040,7 @@ TransducerTable<T> ConvertTransducer::make_transition_table() const
     place = (*it)->append_transitions(transition_table, place);
   }
   transition_table.append(T(false,INFINITE_WEIGHT));
-  
+
   return transition_table;
 }
 
@@ -1061,27 +1052,27 @@ ConvertTransducer::ConvertTransducer(TransduceR * tr, bool weighted):
 {
   constructing_transducer = this;
   id_number_map = new ConvertIdNumberMap(tr);
-  
+
   //std::cout << "Creating state structures" << std::endl;
   read_nodes();
   //std::cout << "Laying out transition table" << std::endl;
   set_transition_table_indices();
   //std::cout << "Laying out transition index table" << std::endl;
   set_index_table_indices();
-  
+
   index_table_size = fst_indices->size();
   delete fst_indices;
-  
+
   //std::cout << "Computing header properties" << std::endl;
   ConvertTransducerHeader::compute_header(
       header, tr, alphabet.get_symbol_table().size(),
       index_table_size,count_transitions(), weighted);
-  
+
   //header.display();
   //alphabet.display();
   //display_states();
   //display_tables();
-  
+
   delete id_number_map;
   id_number_map = NULL;
   constructing_transducer = NULL;
@@ -1118,7 +1109,7 @@ Transducer* ConvertTransducer::to_transducer() const
 int main(int argc, char * argv[])
 {
     std::cout << "Unit tests for " __FILE__ ":" << std::endl;
-    
+
     std::cout << "ok" << std::endl;
     return 0;
 }
