@@ -2,7 +2,6 @@
  * @file hfst-commandline.cc
  *
  * @brief some utils for handling common tasks in command line programs.
- * @todo maybe replace with glib?
  */
 //       This program is free software: you can redistribute it and/or modify
 //       it under the terms of the GNU General Public License as published by
@@ -265,7 +264,9 @@ hfst_strtoweight(const char *s)
 int
 hfst_strtonumber(const char *s, bool *infinite)
 {
-    *infinite = false;
+    if (infinite != NULL) {
+        *infinite = false;
+    }
     errno = 0;
     char *endptr;
     double rv = strtod(s, &endptr);
@@ -425,7 +426,7 @@ hfst_strformat(hfst::ImplementationType format)
     case hfst::UNSPECIFIED_TYPE:
     default:
       return "ERROR (not a HFST supported transducer)";
-      exit(1);
+      //exit(1);
     }
 
 }
@@ -661,6 +662,7 @@ getdelim(char** lineptr, size_t* n, int delim, FILE* stream)
           {
             return -1;
           }
+        *n = nn;
       }
     char* currptr = *lineptr;
     *currptr = '\0';
@@ -713,6 +715,7 @@ getline(char** lineptr, size_t* n, FILE* stream)
           {
              return -1;
           }
+        *n = nn;
       }
     *lineptr = fgets(*lineptr, nn, stream);
     if (*lineptr == NULL)
@@ -856,7 +859,7 @@ print_more_info()
 {
     fprintf(message_out, "%s home page: \n"
             "<%s/%s>\n",
-            WIKI_URL, program_name, hfst_tool_wikiname);
+            program_name, WIKI_URL, hfst_tool_wikiname);
     fprintf(message_out, "General help using HFST software: \n"
             "<%s>\n", WIKI_URL);
 }
