@@ -75,8 +75,8 @@ using hfst::HfstTransducer;
 using hfst::pmatch::PmatchCompiler;
 
 static char *epsilonname=NULL;
-static bool disjunct_expressions=false;
-static bool line_separated = false;
+//static bool disjunct_expressions=false;
+//static bool line_separated = false;
 static bool flatten = false;
 static bool include_cosine_distances = false;
 static clock_t timer;
@@ -170,7 +170,7 @@ parse_options(int argc, char** argv)
     return EXIT_CONTINUE;
 }
 
-#ifndef _GNU_SOURCE
+#if !HAVE_GET_CURRENT_DIR_NAME
 char * get_current_dir_name()
 {
     size_t PATH_BUFSIZE = 1024;
@@ -258,10 +258,10 @@ process_stream(HfstOutputStream& outstream)
         timer = clock();
         std::cerr << "Building hfst-ol alphabet... ";
     }
-    
+
     // A dummy transducer with an alphabet with all the symbols
     HfstTransducer harmonizer(compilation_format);
-    
+
     // First we need to collect a unified alphabet from all the transducers.
     hfst::StringSet symbols_seen;
     for (std::map<std::string, HfstTransducer *>::const_iterator it =
@@ -280,15 +280,12 @@ process_stream(HfstOutputStream& outstream)
         std::cerr << program_name << ": Empty ruleset, nothing to write\n";
         return EXIT_FAILURE;
     }
-    
+
     // Then we convert it...
     harmonizer.convert(hfst::HFST_OLW_TYPE);
     // Use these for naughty intermediate steps to make sure
     // everything has the same alphabet
-    hfst::HfstBasicTransducer * intermediate_tmp;
-    hfst_ol::Transducer * harmonized_tmp;
-    hfst::HfstTransducer * output_tmp;
-    
+
     if (verbose) {
         double duration = (clock() - timer) /
             (double) CLOCKS_PER_SEC;
@@ -296,9 +293,12 @@ process_stream(HfstOutputStream& outstream)
         std::cerr << "built in " << duration << " seconds\n";
         std::cerr << "Converting TOP... ";
     }
-        
+
     // When done compiling everything, look for TOP and output it first.
     if (definitions.count("TOP") == 1) {
+        hfst::HfstBasicTransducer * intermediate_tmp;
+        hfst_ol::Transducer * harmonized_tmp;
+        hfst::HfstTransducer * output_tmp;
         std::map<std::string, std::string> properties = definitions["TOP"]->get_properties();
         intermediate_tmp = hfst::implementations::ConversionFunctions::
             hfst_transducer_to_hfst_basic_transducer(*definitions["TOP"]);
@@ -326,20 +326,28 @@ process_stream(HfstOutputStream& outstream)
             timer = clock();
             std::cerr << "converted in " << duration << " seconds\n";
         }
-    
+
         for (std::map<std::string, HfstTransducer *>::iterator it =
                  definitions.begin(); it != definitions.end(); ++it) {
             if (verbose) {
-                std::cerr << "Converting " << it->first << "... ";
+                std::cerr << "Converting " << it->first << "... " << std::endl;
                 timer = clock();
             }
             intermediate_tmp = hfst::implementations::ConversionFunctions::
                 hfst_transducer_to_hfst_basic_transducer(*(it->second));
-            harmonized_tmp = hfst::implementations::ConversionFunctions::
-                hfst_basic_transducer_to_hfst_ol(intermediate_tmp,
-                                                 true, // weighted
-                                                 "empty_alphabet", // empty alphabet in RTNs, they'll use the main one
-                                                 &harmonizer); // harmonize with this
+            if (it->first.find("UNCOMPOSE") == string::npos) {
+                harmonized_tmp = hfst::implementations::ConversionFunctions::
+                    hfst_basic_transducer_to_hfst_ol(intermediate_tmp,
+                                                     true, // weighted
+                                                     "empty_alphabet", // empty alphabet in RTNs, they'll use the main one
+                                                     &harmonizer); // harmonize with this
+            } else {
+                harmonized_tmp = hfst::implementations::ConversionFunctions::
+                    hfst_basic_transducer_to_hfst_ol(intermediate_tmp,
+                                                     true, // weighted
+                                                     "", // alphabet in UNCs,
+                                                     &harmonizer); // harmonize with this
+            }
             output_tmp = hfst::implementations::ConversionFunctions::
                 hfst_ol_to_hfst_transducer(harmonized_tmp);
             output_tmp->set_name(it->first);
